@@ -61,6 +61,42 @@ async def triple(number):
     await asyncio.sleep(2)
 
 
+@command
+@argument("number", type=int, positional=True)
+def double(number):
+    "Calculates the triple of the input value"
+    cprint("Input is {}".format(number))
+    cprint("Type of input is {}".format(type(number)))
+    cprint("{} * 2 = {}".format(number, number * 2))
+
+@command
+@argument("number", type=int, positional=True)
+@argument("text", type=str)
+def pos_and_kv(number: int, text: str = ''):
+    "Accepts both positional and keyval args"
+    cprint("Input is {}".format(number))
+    cprint(f"The text is {text}")
+
+@command
+@argument("number", type=int, positional=True)
+@argument("text", type=str, positional=True)
+def multipos(number: int, text: str):
+    "Muliple positional args"
+    cprint(f"number is {number}")
+    cprint(f"The text is {text}")
+
+@command
+@argument("number", type=int, positional=True)
+@argument("text", type=str, positional=True)
+@argument("mylist", type=list)
+@argument("mydict", type=dict)
+def multipos_and_kv(number: int, text: str, mylist=None, mydict=None):
+    "Muliple positional args"
+    cprint(f"number is {number}")
+    cprint(f"The text is {text}")
+    cprint(f'mylist is {mylist}')
+    cprint(f'mydict is {mydict}')
+
 @command("be-blocked")
 def be_blocked():
     """
