@@ -17,11 +17,18 @@ from typing_inspect import NEW_TYPING, is_tuple_type, is_typevar, is_union_type
 from nubia.internal.helpers import issubclass_
 
 if NEW_TYPING:
-    from typing import _GenericAlias
+    # from python 3.9 List, Dict are _SpecialGenericAlias type, which with
+    # _GenericAlias is subclass of _BaseGenericAlias
+    try:
+        from typing import _BaseGenericAlias
+        GENERIC_TYPE = _BaseGenericAlias
+    except ImportError:
+        from typing import _GenericAlias
+        GENERIC_TYPE = _GenericAlias
 
 
 def _is_generic_alias_of(this, that) -> bool:
-    return isinstance(this, _GenericAlias) and issubclass_(this.__origin__, that)
+    return isinstance(this, GENERIC_TYPE) and issubclass_(this.__origin__, that)
 
 
 def is_none_type(tp) -> bool:
@@ -39,7 +46,7 @@ def is_mapping_type(tp) -> bool:
 def is_iterable_type(tp) -> bool:
     """Checks whether a type is an iterable type."""
     if NEW_TYPING:
-        return tp is Iterable or tp is List or _is_generic_alias_of(tp, collections.abc.Iterable)
+        return tp is Iterable or _is_generic_alias_of(tp, collections.abc.Iterable)
     return issubclass_(tp, list)
 
 
